#[non_exhaustive]pub struct SolverArcRow {
pub index: usize,
pub branch_index: usize,
pub terminal: SolverArcTerminal,
pub from_bus_index: usize,
pub to_bus_index: usize,
pub tap: f64,
pub shift: f64,
pub g_shunt: f64,
pub b_shunt: f64,
pub rate_a: f64,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.index: usizebranch_index: usizeterminal: SolverArcTerminalfrom_bus_index: usizeto_bus_index: usizetap: f64shift: f64g_shunt: f64b_shunt: f64rate_a: f64Trait Implementations
Sourceimpl Clone for SolverArcRow
impl Clone for SolverArcRow
Sourcefn clone(&self) -> SolverArcRow
fn clone(&self) -> SolverArcRow
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SolverArcRow
impl Debug for SolverArcRow
Sourceimpl<'de> Deserialize<'de> for SolverArcRow
impl<'de> Deserialize<'de> for SolverArcRow
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for SolverArcRow
impl JsonSchema for SolverArcRow
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for SolverArcRow
impl PartialEq for SolverArcRow
Sourcefn eq(&self, other: &SolverArcRow) -> bool
fn eq(&self, other: &SolverArcRow) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for SolverArcRow
impl Serialize for SolverArcRow
impl StructuralPartialEq for SolverArcRow