#[non_exhaustive]pub struct SolverBranchRow {Show 20 fields
pub index: usize,
pub source_row: Option<usize>,
pub from_bus_index: usize,
pub to_bus_index: usize,
pub r: f64,
pub x: f64,
pub b: f64,
pub g_fr: f64,
pub b_fr: f64,
pub g_to: f64,
pub b_to: f64,
pub rate_a: f64,
pub rate_b: f64,
pub rate_c: f64,
pub rating_sets: Vec<BranchRatingSet>,
pub current_ratings: Option<BranchCurrentRatings>,
pub tap: f64,
pub shift: f64,
pub angmin: f64,
pub angmax: f64,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.index: usizesource_row: Option<usize>from_bus_index: usizeto_bus_index: usizer: f64x: f64b: f64g_fr: f64b_fr: f64g_to: f64b_to: f64rate_a: f64rate_b: f64rate_c: f64rating_sets: Vec<BranchRatingSet>current_ratings: Option<BranchCurrentRatings>tap: f64shift: f64angmin: f64angmax: f64Trait Implementations
Sourceimpl Clone for SolverBranchRow
impl Clone for SolverBranchRow
Sourcefn clone(&self) -> SolverBranchRow
fn clone(&self) -> SolverBranchRow
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SolverBranchRow
impl Debug for SolverBranchRow
Sourceimpl<'de> Deserialize<'de> for SolverBranchRow
impl<'de> Deserialize<'de> for SolverBranchRow
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for SolverBranchRow
impl JsonSchema for SolverBranchRow
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for SolverBranchRow
impl PartialEq for SolverBranchRow
Sourcefn eq(&self, other: &SolverBranchRow) -> bool
fn eq(&self, other: &SolverBranchRow) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for SolverBranchRow
impl Serialize for SolverBranchRow
impl StructuralPartialEq for SolverBranchRow