#[non_exhaustive]pub struct SolverBusRow {Show 17 fields
pub index: usize,
pub bus_id: BusId,
pub source_row: Option<usize>,
pub kind: BusType,
pub vm: f64,
pub va: f64,
pub base_kv: f64,
pub vmax: f64,
pub vmin: f64,
pub evhi: Option<f64>,
pub evlo: Option<f64>,
pub area: usize,
pub zone: usize,
pub pd: f64,
pub qd: f64,
pub gs: f64,
pub bs: f64,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.index: usizebus_id: BusIdsource_row: Option<usize>kind: BusTypevm: f64va: f64base_kv: f64vmax: f64vmin: f64evhi: Option<f64>evlo: Option<f64>area: usizezone: usizepd: f64qd: f64gs: f64bs: f64Trait Implementations
Sourceimpl Clone for SolverBusRow
impl Clone for SolverBusRow
Sourcefn clone(&self) -> SolverBusRow
fn clone(&self) -> SolverBusRow
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SolverBusRow
impl Debug for SolverBusRow
Sourceimpl<'de> Deserialize<'de> for SolverBusRow
impl<'de> Deserialize<'de> for SolverBusRow
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for SolverBusRow
impl JsonSchema for SolverBusRow
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for SolverBusRow
impl PartialEq for SolverBusRow
Sourcefn eq(&self, other: &SolverBusRow) -> bool
fn eq(&self, other: &SolverBusRow) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for SolverBusRow
impl Serialize for SolverBusRow
impl StructuralPartialEq for SolverBusRow