#[non_exhaustive]pub struct SolverCostRow {
pub model: u8,
pub startup: f64,
pub shutdown: f64,
pub ncost: usize,
pub coeffs: Vec<f64>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.model: u8startup: f64shutdown: f64ncost: usizecoeffs: Vec<f64>Trait Implementations
Sourceimpl Clone for SolverCostRow
impl Clone for SolverCostRow
Sourcefn clone(&self) -> SolverCostRow
fn clone(&self) -> SolverCostRow
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SolverCostRow
impl Debug for SolverCostRow
Sourceimpl<'de> Deserialize<'de> for SolverCostRow
impl<'de> Deserialize<'de> for SolverCostRow
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl From<&GenCost> for SolverCostRow
impl From<&GenCost> for SolverCostRow
Sourceimpl JsonSchema for SolverCostRow
impl JsonSchema for SolverCostRow
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for SolverCostRow
impl PartialEq for SolverCostRow
Sourcefn eq(&self, other: &SolverCostRow) -> bool
fn eq(&self, other: &SolverCostRow) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for SolverCostRow
impl Serialize for SolverCostRow
impl StructuralPartialEq for SolverCostRow