#[non_exhaustive]pub struct SolverLoadRow {
pub index: usize,
pub source_row: Option<usize>,
pub bus_index: usize,
pub p: f64,
pub q: f64,
pub voltage_model: Option<LoadVoltageModel>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.index: usizesource_row: Option<usize>bus_index: usizep: f64q: f64voltage_model: Option<LoadVoltageModel>Trait Implementations
Sourceimpl Clone for SolverLoadRow
impl Clone for SolverLoadRow
Sourcefn clone(&self) -> SolverLoadRow
fn clone(&self) -> SolverLoadRow
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SolverLoadRow
impl Debug for SolverLoadRow
Sourceimpl<'de> Deserialize<'de> for SolverLoadRow
impl<'de> Deserialize<'de> for SolverLoadRow
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for SolverLoadRow
impl JsonSchema for SolverLoadRow
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for SolverLoadRow
impl PartialEq for SolverLoadRow
Sourcefn eq(&self, other: &SolverLoadRow) -> bool
fn eq(&self, other: &SolverLoadRow) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for SolverLoadRow
impl Serialize for SolverLoadRow
impl StructuralPartialEq for SolverLoadRow