#[non_exhaustive]pub struct SolverShuntRow {
pub index: usize,
pub source_row: Option<usize>,
pub bus_index: usize,
pub g: f64,
pub b: f64,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.index: usizesource_row: Option<usize>bus_index: usizeg: f64b: f64Trait Implementations
Sourceimpl Clone for SolverShuntRow
impl Clone for SolverShuntRow
Sourcefn clone(&self) -> SolverShuntRow
fn clone(&self) -> SolverShuntRow
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SolverShuntRow
impl Debug for SolverShuntRow
Sourceimpl<'de> Deserialize<'de> for SolverShuntRow
impl<'de> Deserialize<'de> for SolverShuntRow
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for SolverShuntRow
impl JsonSchema for SolverShuntRow
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for SolverShuntRow
impl PartialEq for SolverShuntRow
Sourcefn eq(&self, other: &SolverShuntRow) -> bool
fn eq(&self, other: &SolverShuntRow) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for SolverShuntRow
impl Serialize for SolverShuntRow
impl StructuralPartialEq for SolverShuntRow