#[non_exhaustive]pub struct SolverTableIndex {Show 13 fields
pub bus_ids: Vec<BusId>,
pub reference_bus_indices: Vec<usize>,
pub component_labels: Vec<usize>,
pub branch_from_arc_indices: Vec<usize>,
pub branch_to_arc_indices: Vec<usize>,
pub bus_source_rows: Vec<Option<usize>>,
pub load_source_rows: Vec<Option<usize>>,
pub shunt_source_rows: Vec<Option<usize>>,
pub branch_source_rows: Vec<Option<usize>>,
pub switch_source_rows: Vec<Option<usize>>,
pub generator_source_rows: Vec<Option<usize>>,
pub storage_source_rows: Vec<Option<usize>>,
pub hvdc_source_rows: Vec<Option<usize>>,
}Expand description
Identity and provenance vectors that apply across the tables.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.bus_ids: Vec<BusId>Source bus id for each dense bus row. Synthetic 3-winding star buses also receive a stable id in this vector, but have no source row.
reference_bus_indices: Vec<usize>component_labels: Vec<usize>branch_from_arc_indices: Vec<usize>branch_to_arc_indices: Vec<usize>bus_source_rows: Vec<Option<usize>>load_source_rows: Vec<Option<usize>>shunt_source_rows: Vec<Option<usize>>branch_source_rows: Vec<Option<usize>>switch_source_rows: Vec<Option<usize>>generator_source_rows: Vec<Option<usize>>storage_source_rows: Vec<Option<usize>>hvdc_source_rows: Vec<Option<usize>>Trait Implementations
Sourceimpl Clone for SolverTableIndex
impl Clone for SolverTableIndex
Sourcefn clone(&self) -> SolverTableIndex
fn clone(&self) -> SolverTableIndex
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SolverTableIndex
impl Debug for SolverTableIndex
Sourceimpl<'de> Deserialize<'de> for SolverTableIndex
impl<'de> Deserialize<'de> for SolverTableIndex
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for SolverTableIndex
impl JsonSchema for SolverTableIndex
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for SolverTableIndex
impl PartialEq for SolverTableIndex
Sourcefn eq(&self, other: &SolverTableIndex) -> bool
fn eq(&self, other: &SolverTableIndex) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for SolverTableIndex
impl Serialize for SolverTableIndex
impl StructuralPartialEq for SolverTableIndex